@@ -53,8 +53,14 @@ private Q_SLOTS:
     void testConvertFromIncorrectStrippedSvg();
 
     void testEmptyTextChunk();
+    void testTrailingWhitespace();
 
     void testConvertHtmlToSvg();
+    void testTextWithMultipleRelativeOffsets();
+    void testTextWithMultipleAbsoluteOffsetsArabic();
+    void testTextWithMultipleRelativeOffsetsArabic();
+
+    void testTextOutline();
 
 };
 
