@@ -48,7 +48,8 @@ public:
                               const QRect& rect,
                               qreal xRadius, qreal yRadius,
                               const QBitArray &channelFlags,
-                              KoUpdater *updater);
+                              KoUpdater *updater,
+                              bool createTransaction = false);
 
     static Eigen::Matrix<qreal, Eigen::Dynamic, Eigen::Dynamic> createLoGMatrix(qreal radius, qreal coeff = 1.0);
 
@@ -65,13 +66,15 @@ public:
                             const QRect& rect,
                             qreal radius,
                             const QBitArray &channelFlags,
-                            KoUpdater *progressUpdater);
+                            KoUpdater *progressUpdater,
+                            bool createTransaction = false);
 
     static void applyErodeU8(KisPaintDeviceSP device,
                              const QRect& rect,
                              qreal radius,
                              const QBitArray &channelFlags,
-                             KoUpdater *progressUpdater);
+                             KoUpdater *progressUpdater,
+                             bool createTransaction = false);
 };
 
 #endif /* __KIS_GAUSSIAN_KERNEL_H */
