@@ -143,7 +143,7 @@ GeneralTab::GeneralTab(QWidget *_parent, const char *_name)
 
     const QString configPath = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation);
     QSettings kritarc(configPath + QStringLiteral("/kritadisplayrc"), QSettings::IniFormat);
-    m_chkHiDPI->setChecked(kritarc.value("EnableHiDPI", false).toBool());
+    m_chkHiDPI->setChecked(kritarc.value("EnableHiDPI", true).toBool());
 
     m_chkSingleApplication->setChecked(kritarc.value("EnableSingleApplication", true).toBool());
 
@@ -189,8 +189,6 @@ GeneralTab::GeneralTab(QWidget *_parent, const char *_name)
 
     chkShowRootLayer->setChecked(cfg.showRootLayer());
 
-    m_hideSplashScreen->setChecked(cfg.hideSplashScreen());
-
     KConfigGroup group = KSharedConfig::openConfig()->group("File Dialogs");
     bool dontUseNative = true;
 #ifdef Q_OS_UNIX
@@ -220,7 +218,6 @@ void GeneralTab::setDefault()
     m_backupFileCheckBox->setChecked(cfg.backupFile(true));
     m_showOutlinePainting->setChecked(cfg.showOutlineWhilePainting(true));
     m_changeBrushOutline->setChecked(!cfg.forceAlwaysFullSizedOutline(true));
-    m_hideSplashScreen->setChecked(cfg.hideSplashScreen(true));
 
     m_chkNativeFileDialog->setChecked(false);
     intMaxBrushSize->setValue(1000);
@@ -295,11 +292,6 @@ bool GeneralTab::showOutlineWhilePainting()
     return m_showOutlinePainting->isChecked();
 }
 
-bool GeneralTab::hideSplashScreen()
-{
-    return m_hideSplashScreen->isChecked();
-}
-
 int GeneralTab::mdiMode()
 {
     return m_cmbMDIType->currentIndex();
@@ -838,6 +830,12 @@ void PerformanceTab::load(bool requestDefault)
         chkBackgroundCacheGeneration->setChecked(cfg2.calculateAnimationCacheInBackground(requestDefault));
     }
 
+#ifdef Q_OS_WIN
+    optOnDisk->setChecked(false);
+    optOnDisk->setEnabled(false);
+    optInMemory->setEnabled(false);
+#endif
+
     if (cfg.useOnDiskAnimationCacheSwapping(requestDefault)) {
         optOnDisk->setChecked(true);
     } else {
@@ -1312,7 +1310,6 @@ bool KisDlgPreferences::editPreferences()
         cfg.setShowRootLayer(dialog->m_general->showRootLayer());
         cfg.setShowOutlineWhilePainting(dialog->m_general->showOutlineWhilePainting());
         cfg.setForceAlwaysFullSizedOutline(!dialog->m_general->m_changeBrushOutline->isChecked());
-        cfg.setHideSplashScreen(dialog->m_general->hideSplashScreen());
         cfg.setSessionOnStartup(dialog->m_general->sessionOnStartup());
         cfg.setSaveSessionOnQuit(dialog->m_general->saveSessionOnQuit());
 
