@@ -23,6 +23,7 @@
 #include <KoColor.h>
 #include "stroke_testing_utils.h"
 #include "strokes/freehand_stroke.h"
+#include "strokes/KisFreehandStrokeInfo.h"
 #include "kis_resources_snapshot.h"
 #include "kis_image.h"
 #include "kis_painter.h"
@@ -37,6 +38,7 @@ public:
           m_useLod(useLod),
           m_flipLineDirection(false)
     {
+        setBaseFuzziness(3);
     }
 
     void setFlipLineDirection(bool value) {
@@ -50,7 +52,7 @@ public:
 
 protected:
     using utils::StrokeTester::initImage;
-    void initImage(KisImageWSP image, KisNodeSP activeNode) {
+    void initImage(KisImageWSP image, KisNodeSP activeNode) override {
         Q_UNUSED(activeNode);
 
         if (m_useLod) {
@@ -58,7 +60,7 @@ protected:
         }
     }
 
-    void beforeCheckingResult(KisImageWSP image, KisNodeSP activeNode) {
+    void beforeCheckingResult(KisImageWSP image, KisNodeSP activeNode) override {
         Q_UNUSED(image)
         Q_UNUSED(activeNode);
 
@@ -68,7 +70,7 @@ protected:
     }
 
     void modifyResourceManager(KoCanvasResourceManager *manager,
-                               KisImageWSP image)
+                               KisImageWSP image) override
     {
         modifyResourceManager(manager, image, 0);
     }
@@ -76,7 +78,7 @@ protected:
 
     void modifyResourceManager(KoCanvasResourceManager *manager,
                                KisImageWSP image,
-                               int iteration) {
+                               int iteration) override {
 
         if (m_paintColor && iteration > 0) {
             QVariant i;
@@ -85,27 +87,27 @@ protected:
         }
     }
 
-    KisStrokeStrategy* createStroke(bool indirectPainting,
-                                    KisResourcesSnapshotSP resources,
-                                    KisImageWSP image) {
+    KisStrokeStrategy* createStroke(KisResourcesSnapshotSP resources,
+                                    KisImageWSP image) override {
         Q_UNUSED(image);
 
-        FreehandStrokeStrategy::PainterInfo *painterInfo =
-            new FreehandStrokeStrategy::PainterInfo();
+        KisFreehandStrokeInfo *strokeInfo = new KisFreehandStrokeInfo();
 
         QScopedPointer<FreehandStrokeStrategy> stroke(
-            new FreehandStrokeStrategy(indirectPainting, COMPOSITE_ALPHA_DARKEN, resources, painterInfo, kundo2_noi18n("Freehand Stroke")));
+            new FreehandStrokeStrategy(resources, strokeInfo, kundo2_noi18n("Freehand Stroke")));
 
         return stroke.take();
     }
 
-    virtual void addPaintingJobs(KisImageWSP image,
-                                 KisResourcesSnapshotSP resources)
+    void addPaintingJobs(KisImageWSP image,
+                                 KisResourcesSnapshotSP resources) override
     {
         addPaintingJobs(image, resources, 0);
     }
 
-    void addPaintingJobs(KisImageWSP image, KisResourcesSnapshotSP resources, int iteration) {
+    void addPaintingJobs(KisImageWSP image, KisResourcesSnapshotSP resources, int iteration) override {
+        Q_UNUSED(resources);
+
         KisPaintInformation pi1;
         KisPaintInformation pi2;
 
@@ -118,14 +120,14 @@ protected:
         }
 
         QScopedPointer<KisStrokeJobData> data(
-            new FreehandStrokeStrategy::Data(resources->currentNode(),
-                                             0, pi1, pi2));
+            new FreehandStrokeStrategy::Data(0, pi1, pi2));
 
         image->addJob(strokeId(), data.take());
+        image->addJob(strokeId(), new FreehandStrokeStrategy::UpdateData(true));
     }
 
 private:
-    FreehandStrokeStrategy::PainterInfo *m_painterInfo;
+    KisFreehandStrokeInfo *m_strokeInfo;
     bool m_useLod;
     bool m_flipLineDirection;
     QScopedPointer<QColor> m_paintColor;
