@@ -53,14 +53,14 @@ public:
     /**
      * Destructor
      */
-    virtual ~KoColorSetWidget();
+    ~KoColorSetWidget() override;
 
     /**
      * Sets the color set that this widget shows.
      * @param colorSet pointer to the color set
      */
-    void setColorSet(KoColorSet *colorSet);
-    
+    void setColorSet(QPointer<KoColorSet> colorSet);
+
     /**
      * @brief setDisplayRenderer
      * Set the display renderer of this object.
@@ -75,7 +75,7 @@ public:
     KoColorSet* colorSet();
 
 protected:
-    virtual void resizeEvent(QResizeEvent *event); ///< reimplemented from QFrame
+    void resizeEvent(QResizeEvent *event) override; ///< reimplemented from QFrame
 
 Q_SIGNALS:
 
